/********************************************************************************
*                                                                               *
*                                 Dialspin Test                                 *
*                                                                               *
*********************************************************************************
* Copyright (C) 2004 by Bill Baxter.                All Rights Reserved.        *
*********************************************************************************
* $Id: Dialspin.cpp,v 1.14 2003/10/05 17:16:27 fox Exp $                        *
********************************************************************************/
#include "fx.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "FXRealSpinDial.h"


/*******************************************************************************/


// Mini application object
class SpinDialWindow : public FXMainWindow {
  FXDECLARE(SpinDialWindow)
protected:
  FXStatusBar*       statusbar;     // Status line
  FXHorizontalFrame* columns;       // splits columns
  FXVerticalFrame*   leftcol;
  FXVerticalFrame*   rightcol;
  float              data;
  FXDataTarget       dataTarget;
protected:
  SpinDialWindow(){}
public:
  enum {
    // Message to quit application
    ID_QUIT=FXMainWindow::ID_LAST
    };
public:
  long onCmdIconTextRelation(FXObject*,FXSelector,void*);
  long onUpdIconTextRelation(FXObject*,FXSelector,void*);

  long onCmdJustification(FXObject*,FXSelector,void*);
  long onUpdJustification(FXObject*,FXSelector,void*);

  long onCmdToolbarStyle(FXObject*,FXSelector,void*);

  long onCmdQuit(FXObject*,FXSelector,void*);
public:
  SpinDialWindow(FXApp* a);
  void create();
  virtual ~SpinDialWindow();
  };


/*******************************************************************************/


/*******************************************************************************/


// Map
FXDEFMAP(SpinDialWindow) SpinDialWindowMap[]={
  // Quit
  FXMAPFUNC(SEL_CLOSE,    0,                                 SpinDialWindow::onCmdQuit),
  FXMAPFUNC(SEL_COMMAND,  SpinDialWindow::ID_QUIT,             SpinDialWindow::onCmdQuit),
  };


// SpinDialApp implementation
FXIMPLEMENT(SpinDialWindow,FXMainWindow,SpinDialWindowMap,ARRAYNUMBER(SpinDialWindowMap))



// Make some windows
SpinDialWindow::SpinDialWindow(FXApp* a):
  FXMainWindow(a,"SpinDial Test",NULL,NULL,
    DECOR_TITLE|DECOR_MINIMIZE|DECOR_MAXIMIZE|DECOR_CLOSE|DECOR_BORDER|DECOR_STRETCHABLE|DECOR_MENU,
    100,100)  {

  // Tooltip
  new FXToolTip(getApp());

  // Status bar
  statusbar=new FXStatusBar(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|STATUSBAR_WITH_DRAGCORNER);



  // Contents
  columns=new FXHorizontalFrame(this,LAYOUT_SIDE_LEFT|FRAME_NONE|LAYOUT_FILL,0,0,0,0,20,20,20,20);
  // Controls on left
  leftcol=new FXVerticalFrame(columns,LAYOUT_SIDE_LEFT|PACK_UNIFORM_WIDTH);
  // Separator
  new FXVerticalSeparator(columns,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y|SEPARATOR_GROOVE);
  // Controls on right
  rightcol=new FXVerticalFrame(columns,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH);

  // The SpinDial
  dataTarget.connect(data);
  FXDataTarget *d = &dataTarget;
  FXSelector s = d->ID_VALUE;
  FXuint opt=LAYOUT_TOP|FRAME_SUNKEN|FRAME_THICK;
  FXRealSpinDial *sp;
  new FXLabel(leftcol, "Basic control options");
  new FXLabel(leftcol, "Text,buttons,dial:");
  sp = new FXRealSpinDial(leftcol, 15, d, s,opt);
  sp->setRange(0,100);
  new FXLabel(leftcol, "Text,dial:");
  sp = new FXRealSpinDial(leftcol, 15, d, s,SPINDIAL_NOBUTTONS|opt);
  sp->setRange(-200,200);
  new FXLabel(leftcol, "Text,buttons:");
  sp = new FXRealSpinDial(leftcol, 15, d, s,SPINDIAL_NODIAL|opt);
  sp->setRange(0,100);
  new FXLabel(leftcol, "buttons,dial:");
  sp = new FXRealSpinDial(leftcol, 15, d, s,SPINDIAL_NOTEXT|opt);
  sp->setRange(0,100);
  new FXLabel(leftcol, "text only:");
  sp = new FXRealSpinDial(leftcol, 15, d, s,SPINDIAL_NODIAL|SPINDIAL_NOBUTTONS|opt);
  sp->setRange(0,100);
  new FXLabel(leftcol, "buttons only:");
  sp = new FXRealSpinDial(leftcol, 15, d, s,SPINDIAL_NODIAL|SPINDIAL_NOTEXT|opt);
  sp->setRange(0,100);
  new FXLabel(leftcol, "dial only:");
  sp = new FXRealSpinDial(leftcol, 15, d, s,SPINDIAL_NOBUTTONS|SPINDIAL_NOTEXT|opt);
  sp->setRange(0,100);

  new FXHorizontalSeparator(leftcol,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE);

  new FXLabel(leftcol, "Cyclic spinner");
  sp = new FXRealSpinDial(leftcol, 15, d, s,SPINDIAL_CYCLIC|opt);
  sp->setRange(0,100);


  new FXLabel(rightcol, "Various number formats and increments");
  new FXLabel(rightcol, "Smaller increment and range:");
  sp = new FXRealSpinDial(rightcol, 15, d, s,SPINDIAL_NOBUTTONS|opt);
  sp->setIncrements(0.01,0.1,1);
  sp->setRange(0,20);

  new FXLabel(rightcol, "One digit precision:");
  sp = new FXRealSpinDial(rightcol, 15, d, s,SPINDIAL_NOBUTTONS|opt);
  sp->setNumberFormat(1,FALSE);
  sp->setRange(0,100);

  new FXLabel(rightcol, "Money, using format string:");
  sp = new FXRealSpinDial(rightcol, 15, d, s,SPINDIAL_NOBUTTONS|opt);
  sp->setFormatString("$%.2f");
  sp->setRange(0,20);

  new FXHorizontalSeparator(rightcol,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE);

  new FXLabel(rightcol, "Logarithmic spinner");

  sp = new FXRealSpinDial(rightcol, 15, d, s,SPINDIAL_LOG|opt);
  sp->setIncrements(1.1,2,100);
  sp->setValue(1);
  sp->setNumberFormat(4,TRUE);
  sp->setRange(1e-15,1e15);

  new FXLabel(rightcol, "Cyclic logarithmic spinner");
  sp = new FXRealSpinDial(rightcol, 15, d, s,SPINDIAL_LOG|SPINDIAL_CYCLIC|opt);
  sp->setIncrements(1.1,2,100);
  sp->setValue(1);
  sp->setNumberFormat(4,TRUE);
  sp->setRange(1e-15,1e15);

  new FXHorizontalSeparator(rightcol,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE);

  new FXLabel(rightcol, "Things to try: \n"
    "Hold down CONTROL during click and drag\n"
    "Hold down SHIFT during click and drag\n"
    "Drag dial off the top of screen\n"
    "Type up key and down key\n"
    "Also up + down holding CTRL or SHIFT\n"
    "Drag dial with right mouse button"


    );

  new FXButton(rightcol,"&Quit",NULL,this,ID_QUIT,FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_BOTTOM);
  }


// Free up icon
SpinDialWindow::~SpinDialWindow(){
  delete icon;
  }
  
  
// Start
void SpinDialWindow::create(){
  FXMainWindow::create();
  show(PLACEMENT_SCREEN);
  }






// Quit the application
long SpinDialWindow::onCmdQuit(FXObject*,FXSelector,void*){
  getApp()->exit(0);
  return 1;
  }

/*******************************************************************************/


// Start the whole thing
int main(int argc,char *argv[]){

  // Make application
  FXApp application("SpinDial","FoxTest");

  // Open display
  application.init(argc,argv);

  // Main window
  new SpinDialWindow(&application);

  // Create app
  application.create();

  // Run
  return application.run();
  }


